@@ -1,7 +1,7 @@
 package Getopt::Long::Complete;
 
-our $DATE = '2015-04-30'; # DATE
-our $VERSION = '0.25'; # VERSION
+our $DATE = '2015-12-30'; # DATE
+our $VERSION = '0.26'; # VERSION
 
 use 5.010001;
 use strict;
@@ -48,7 +48,7 @@ sub GetOptionsWithCompletion {
         my ($words, $cword);
         if ($ENV{COMP_LINE}) {
             require Complete::Bash;
-            ($words,$cword) = @{ Complete::Bash::parse_cmdline() };
+            ($words,$cword) = @{ Complete::Bash::parse_cmdline(undef, undef, {truncate_current_word=>1}) };
         } elsif ($ENV{COMMAND_LINE}) {
             require Complete::Tcsh;
             $shell = 'tcsh';
@@ -110,7 +110,7 @@ Getopt::Long::Complete - A drop-in replacement for Getopt::Long, with shell tab
 
 =head1 VERSION
 
-This document describes version 0.25 of Getopt::Long::Complete (from Perl distribution Getopt-Long-Complete), released on 2015-04-30.
+This document describes version 0.26 of Getopt::Long::Complete (from Perl distribution Getopt-Long-Complete), released on 2015-12-30.
 
 =head1 SYNOPSIS
 
